@@ -5,7 +5,7 @@
  * software
  */
 /*
- * $Id: huffd.c,v 1.6 2004/08/18 21:38:43 enlf Exp $
+ * $Id: huffd.c,v 1.7 2005/05/15 22:10:20 enlf Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -426,9 +426,13 @@ void DecodeFirstRow (DecompressInfo *dcPtr, MCU *curRowBuf)
          */
         HuffDecode (dctbl,s);
         if (s) {
-           get_bits(s,d);
-           HuffExtend(d,s);
-           } else {
+           if (s == 16) {      /* special case: always output 32768 */
+              d = 32768;
+           } else {            /* normal  case: fetch subsequent bits */
+              get_bits(s,d);
+              HuffExtend(d,s);
+           }
+        } else {
            d = 0;
         }
 
@@ -452,9 +456,13 @@ void DecodeFirstRow (DecompressInfo *dcPtr, MCU *curRowBuf)
              */
             HuffDecode (dctbl,s);
             if (s) {
-               get_bits(s,d);
-               HuffExtend(d,s);
-               } else {
+               if (s == 16) {      /* special case: always output 32768 */
+                  d = 32768;
+               } else {            /* normal  case: fetch subsequent bits */
+                  get_bits(s,d);
+                  HuffExtend(d,s);
+               }
+            } else {
                d = 0;
             }
 
@@ -555,8 +563,17 @@ void DecodeImage (DecompressInfo *dcPtr, unsigned short **image, int depth)
           /* Upper neighbor is predictor for the first column */
           /* Section F.2.2.1: decode the difference */
           HuffDecode (dctbl,s);
-          if (s) { get_bits(s,d); HuffExtend(d,s); } 
-          else d = 0;
+          if (s) {
+             if (s == 16) {      /* special case: always output 32768 */
+                d = 32768;
+             } else {            /* normal  case: fetch subsequent bits */
+                get_bits(s,d);
+                HuffExtend(d,s);
+             }
+          } else {
+             d = 0;
+          }
+
           *curPixelPtr = (unsigned char) (d + *(curPixelPtr - numCOL));
           curPixelPtr++;
 
@@ -564,8 +581,16 @@ void DecodeImage (DecompressInfo *dcPtr, unsigned short **image, int depth)
             for (col=1; col < numCOL; col++) {
               /* Section F.2.2.1: decode the difference */
               HuffDecode (dctbl, s);
-              if (s) { get_bits (s, d); HuffExtend (d, s); }
-              else d = 0;
+              if (s) {
+                 if (s == 16) {      /* special case: always output 32768 */
+                    d = 32768;
+                 } else {            /* normal  case: fetch subsequent bits */
+                    get_bits(s,d);
+                    HuffExtend(d,s);
+                 }
+              } else {
+                 d = 0;
+              }
 
               *curPixelPtr = (unsigned char) (d + *(curPixelPtr - 1));
               curPixelPtr++;
@@ -576,8 +601,16 @@ void DecodeImage (DecompressInfo *dcPtr, unsigned short **image, int depth)
             for (col=1; col < numCOL; col++) {
               /* Section F.2.2.1: decode the difference */
               HuffDecode (dctbl, s);
-              if (s) { get_bits (s, d); HuffExtend (d, s); }
-              else d = 0;
+              if (s) {
+                 if (s == 16) {      /* special case: always output 32768 */
+                    d = 32768;
+                 } else {            /* normal  case: fetch subsequent bits */
+                    get_bits(s,d);
+                    HuffExtend(d,s);
+                 }
+              } else {
+                 d = 0;
+              }
 
               /* Predict : All predictors are calculated according to psv */
               switch (psv) {
@@ -655,8 +688,16 @@ void DecodeImage (DecompressInfo *dcPtr, unsigned short **image, int depth)
 
             /* Section F.2.2.1: decode the difference */
             HuffDecode (dctbl,s);
-            if (s) { get_bits(s,d); HuffExtend(d,s); } 
-            else d = 0;
+            if (s) {
+               if (s == 16) {      /* special case: always output 32768 */
+                  d = 32768;
+               } else {            /* normal  case: fetch subsequent bits */
+                  get_bits(s,d);
+                  HuffExtend(d,s);
+               }
+            } else {
+               d = 0;
+            }
 
             curRowBuf[0][curComp]=d+prevRowBuf[0][curComp];
         }/*endfor curComp*/
@@ -671,8 +712,16 @@ void DecodeImage (DecompressInfo *dcPtr, unsigned short **image, int depth)
 
                 /* Section F.2.2.1: decode the difference */
                 HuffDecode (dctbl, s);
-                if (s) { get_bits (s, d); HuffExtend (d, s); }
-                else d = 0;
+                if (s) {
+                   if (s == 16) {      /* special case: always output 32768 */
+                      d = 32768;
+                   } else {            /* normal  case: fetch subsequent bits */
+                      get_bits(s,d);
+                      HuffExtend(d,s);
+                   }
+                } else {
+                   d = 0;
+                }
 
                 QuickPredict (col,curComp,curRowBuf,prevRowBuf,psv,&predictor);
 
