@@ -25,7 +25,6 @@
  *                MdcWriteLine()        - Write image line                 *
  *                MdcWriteDoublePixel() - Write single pixel double input  *
  *                MdcGetFname()         - Get filename                     *
- *                MdcGetExtension()     - Get filename original extension  *
  *                MdcSetExt()           - Set filename extension           *
  *                MdcNewExt()           - Create filename extension        *
  *                MdcPrefix()           - Create filename prefix           * 
@@ -47,11 +46,11 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.110 2009/05/14 20:12:17 enlf Exp $ 
+/* $Id: m-files.c,v 1.113 2010/08/28 23:44:23 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2009 by Erik Nolf
+   Copyright (C) 1997-2010 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -948,24 +947,6 @@ char *MdcGetFname(char path[])
   return(p+1); 
 }
 
-char *MdcGetExtension(char path[])
-{
-  char *p=NULL, *ext=NULL;
-
-  if (path != NULL) {
-    p=(char *)strrchr(path,'.');
-
-    if (p != NULL) {
-      ext=malloc(strlen(p)+1);
-      p+=1; /* without the dot */
-      if (ext != NULL) strcpy(ext,p);
-    }
-  }
-
-  return(ext);
-
-} 
-
 void MdcSetExt(char path[], char *ext)
 {
   char *p;
@@ -999,7 +980,7 @@ void MdcNewExt(char dest[], char *src, char *ext)
       }
     }else{
       /* single basename */
-      strncat(dest,mdcbasename,MDC_MAX_PATH);
+      strncpy(dest,mdcbasename,MDC_MAX_PATH);
     }
   }else{
     /* default output name */
