@@ -16,11 +16,11 @@
  *                MdcWriteINW()         - Write INW file                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-inw.c,v 1.38 2009/05/14 20:12:17 enlf Exp $
+/* $Id: m-inw.c,v 1.40 2010/08/28 23:44:23 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2009 by Erik Nolf
+   Copyright (C) 1997-2010 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -374,8 +374,8 @@ int MdcWriteHeadGen(FILEINFO *fi)
   hg.scanner    = 0;
   hg.reconstruction = '?';
   hg.recon_version  = 0;
-  sprintf(hg.day,"%.11s ",MDC_DATE);
-  sprintf(hg.reserved,"%.23s",MDC_PRGR);
+  strncpy(hg.day,MDC_DATE,12);
+  strncpy(hg.reserved,MDC_PRGR,24);
 
   MdcMakeVAXfl(hg.decay_cst);    MdcMakeVAXfl(hg.pixel_size);
   MdcMakeVAXfl(hg.max);          MdcMakeVAXfl(hg.min);
